# reports
Models, charts, and tables generated from Antelope catalogs. Heavyweight with pandas, plots, etc.

This package is a collection of useful support tools that (a) are not required in core Antelope and (b) do
or may require heavyweight support packages that would not be desirable in a "slender" install.

The utilities are grouped into several categories, each described briefly below.

The general support level of this code is "late alpha".  Most of these tools work, and many of them are 
used in production. But they are not CI-ed and may not be well documented.

## charts

Graphical visualizations of LCA results. 